@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative 'test_helper'
 
 # Kernel test class
@@ -10,14 +12,20 @@ class KernelTest < Minitest::Test
   end
 
   def test_can_exec_normally
-    out = open("|echo 'foo'")
-    assert_equal "foo\n", out.gets
+    skip if RUBY_VERSION >= '4.0'
+    silence_warnings do
+      out = open("|echo 'foo'")
+      assert_equal "foo\n", out.gets
+    end
   end
 
   def test_fake_kernel_can_create_subprocesses
+    skip if RUBY_VERSION >= '4.0'
     FakeFS do
-      out = open("|echo 'foo'")
-      assert_equal "foo\n", out.gets
+      silence_warnings do
+        out = open("|echo 'foo'")
+        assert_equal "foo\n", out.gets
+      end
     end
   end
 
@@ -49,8 +57,11 @@ class KernelTest < Minitest::Test
   end
 
   def test_can_exec_normally2
-    out = open("|echo 'foo'")
-    assert_equal "foo\n", out.gets
+    skip if RUBY_VERSION >= '4.0'
+    silence_warnings do
+      out = open("|echo 'foo'")
+      assert_equal "foo\n", out.gets
+    end
   end
 
   def test_kernel_open_can_handle_kwargs_after_deactivation
